import { React, PropTypes, FormattedMessage } from '../../dependencies';

import Messages from '../../containers/Messages';
import MessageForm from '../../containers/MessageForm';

var Conversation = function Conversation(_ref) {
    var userId = _ref.userId,
        conversationId = _ref.conversationId,
        isLoaded = _ref.isLoaded,
        header = _ref.header,
        loader = _ref.loader,
        filesEnabled = _ref.filesEnabled,
        sendLabel = _ref.sendLabel,
        uploadLabel = _ref.uploadLabel,
        loadingPlaceholder = _ref.loadingPlaceholder,
        MessageAuthor = _ref.MessageAuthor,
        MessageImage = _ref.MessageImage;
    return React.createElement(
        'div',
        { className: 'conversation' },
        isLoaded && React.createElement(
            React.Fragment,
            null,
            header,
            React.createElement(Messages, {
                userId: userId,
                conversationId: conversationId,
                loadingPlaceholder: loadingPlaceholder,
                MessageAuthor: MessageAuthor,
                MessageImage: MessageImage
            }),
            React.createElement(MessageForm, {
                userId: userId,
                conversationId: conversationId,
                filesEnabled: filesEnabled,
                sendLabel: sendLabel,
                uploadLabel: uploadLabel
            })
        ),
        !isLoaded && loader
    );
};

Conversation.propTypes = {
    conversationId: PropTypes.string.isRequired,
    userId: PropTypes.string.isRequired,
    isLoaded: PropTypes.bool.isRequired,
    header: PropTypes.node,
    loader: PropTypes.node,
    // message form customization props
    filesEnabled: PropTypes.bool,
    sendLabel: PropTypes.node,
    uploadLabel: PropTypes.node,
    newMessageInput: PropTypes.node,
    // messages customization props
    loadingPlaceholder: PropTypes.node,
    MessageAuthor: PropTypes.func,
    MessageImage: PropTypes.func
};

Conversation.defaultProps = {
    conversation: {},
    header: null,
    loader: React.createElement(FormattedMessage, { id: 'chat.messages.loading' }),
    filesEnabled: undefined,
    sendLabel: undefined,
    uploadLabel: undefined,
    newMessageInput: undefined,
    loadingPlaceholder: undefined,
    MessageAuthor: undefined,
    MessageImage: undefined
};

export default Conversation;