'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _dependencies = require('../../dependencies');

var _FileUpload = require('./FileUpload');

var _FileUpload2 = _interopRequireDefault(_FileUpload);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var MessageForm = function MessageForm(_ref) {
    var conversationId = _ref.conversationId,
        userId = _ref.userId,
        handleSubmit = _ref.handleSubmit,
        actions = _ref.actions,
        intl = _ref.intl,
        pristine = _ref.pristine,
        submitting = _ref.submitting,
        sendLabel = _ref.sendLabel,
        filesEnabled = _ref.filesEnabled,
        uploadLabel = _ref.uploadLabel,
        newMessageInput = _ref.newMessageInput;
    return _dependencies.React.createElement(
        'div',
        { className: 'conversation__message-form' },
        _dependencies.React.createElement(
            _dependencies.Form,
            { className: 'form', onSubmit: handleSubmit },
            filesEnabled && _dependencies.React.createElement(_FileUpload2.default, {
                userId: userId,
                conversationId: conversationId,
                uploadLabel: uploadLabel,
                onUploadFile: actions.uploadImage
            }),
            _dependencies.React.createElement(_dependencies.Field, {
                name: 'text',
                type: 'text',
                component: newMessageInput,
                placeholder: intl.formatMessage({ id: 'chat.message.new.placeholder' })
            }),
            _dependencies.React.createElement(
                'button',
                { disabled: pristine || submitting, type: 'submit' },
                sendLabel
            )
        )
    );
};

MessageForm.propTypes = {
    // userId and conversationId are used by container, but since they're important
    // props, we're typechecking them here
    userId: _dependencies.PropTypes.string.isRequired,
    conversationId: _dependencies.PropTypes.string.isRequired,

    handleSubmit: _dependencies.PropTypes.func.isRequired,
    intl: _dependencies.intlShape.isRequired,
    actions: _dependencies.PropTypes.shape({
        uploadImage: _dependencies.PropTypes.func
    }).isRequired,
    pristine: _dependencies.PropTypes.bool.isRequired,
    submitting: _dependencies.PropTypes.bool.isRequired,
    filesEnabled: _dependencies.PropTypes.bool,
    sendLabel: _dependencies.PropTypes.node,
    uploadLabel: _dependencies.PropTypes.node,
    newMessageInput: _dependencies.PropTypes.oneOfType([_dependencies.PropTypes.string, _dependencies.PropTypes.func])
};

MessageForm.defaultProps = {
    filesEnabled: false,
    uploadLabel: undefined,
    sendLabel: _dependencies.React.createElement(_dependencies.FormattedMessage, { id: 'chat.message.new.send' }),
    newMessageInput: 'input'
};

exports.default = (0, _dependencies.injectIntl)(MessageForm);